/*
 * This file is part of Bitsquare.
 *
 * Bitsquare is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 *
 * Bitsquare is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Bitsquare. If not, see <http://www.gnu.org/licenses/>.
 */

package io.bitsquare.trade.protocol.placeoffer.tasks;

import io.bitsquare.trade.protocol.placeoffer.PlaceOfferModel;
import io.bitsquare.common.taskrunner.Task;
import io.bitsquare.common.taskrunner.TaskRunner;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class AddOfferToRemoteOfferBook extends Task<PlaceOfferModel> {
    private static final Logger log = LoggerFactory.getLogger(AddOfferToRemoteOfferBook.class);

    public AddOfferToRemoteOfferBook(TaskRunner taskHandler, PlaceOfferModel model) {
        super(taskHandler, model);
        appendToErrorMessage("Could not add offer to offerbook. Maybe you have connection problems. Please try later again.");
    }

    @Override
    protected void doRun() {
        model.getOfferBookService().addOffer(model.getOffer(),
                () -> {
                    complete();
                },
                (message, throwable) -> {
                    failed(throwable);
                });
    }

    @Override
    protected void updateStateOnFault() {
        // do nothing
    }
}
